/*
 *	Simple MUlti-Gigabyte FileSystem 1.0
 *
 *	(c) 1998 Martin Mares <mj@ucw.cz>
 */

struct smug_super_block {
	__u32 magic;
	__u32 version;
	__u32 flags;					    /* Various flags (see below) */
	__u32 num_groups;				    /* Total number of groups in the fs (<256) */
	__u32 total_blocks;				    /* Total number of blocks in the fs */
	__u32 first_group_block;			    /* First block of first group */
	__u32 first_dir_block;				    /* First block of directory */
	__u32 num_dir_blocks;				    /* Number of directory blocks */
};

#define SMUG_SUPER_MAGIC 0x534d5547
#define SMUG_VERSION 0x10000

#define SMUG_FLAG_CLEAN 1

struct smug_super {					    /* In-memory copy of the super-block */
	__u32 old_flags;				    /* Original flags */
	unsigned int total_blocks;
	unsigned int num_groups;			    /* Groups */
	unsigned int first_group_block;
	unsigned int blocks_per_group;
	unsigned int first_dir_block;			    /* Directory */
	unsigned int num_dir_blocks;

	struct buffer_head *super_bh;			    /* Buffer head holding the superblock */

	unsigned long dir_bitmap[256 / sizeof(unsigned long)]; /* Allocated dir entries */
	unsigned long valid_dir_bitmap[256 / sizeof(unsigned long)]; /* Valid dir entries */
	unsigned long group_bitmap[256 / sizeof(unsigned long)];
};

#define SMUG_ROOT_INODE 0

struct smug_inode {
	__u32 magic;
	__u32 type;
	__u32 uid, gid, mode;
	__u32 rfu;
	__u64 size;
	__u32 mtime, ctime;
	unsigned char name[256];
	__u8 block_map[256];
};

#define SMUG_INO_MAGIC 0x37dc2a8b

#define SMUG_INO_TYPE_FREE 0
#define SMUG_INO_TYPE_FILE 1
#define SMUG_INO_TYPE_ROOT 2
